IContentPage

Struct IContentPage 

pub struct IContentPage(/* private fields */);
The IContentPage interface is used to define a content page in the Command Palette. Content pages can be used to display additional information or resources related to the item being displayed in the Command Palette.

Implementations

Source

impl IContentPage

pub fn GetContent(&self) -> Result<Array<IContent>>

The GetContent method retrieves the content associated with the content page. This method is used to display additional information or resources related to the item being displayed in the Command Palette.

pub fn Details(&self) -> Result<IDetails>

The details associated with the content page.

pub fn Commands(&self) -> Result<Array<IContextItem>>

The commands associated with the content page.

pub fn Name(&self) -> Result<HSTRING>

Gets the name of the command.

pub fn Id(&self) -> Result<HSTRING>

Gets the ID of the command. This is optional but can help support more efficient command lookup in ICommandProvider::GetCommand.

pub fn Icon(&self) -> Result<IIconInfo>

Gets the icon of the command.

pub fn ItemsChanged<P0>(&self, handler: P0) -> Result<i64>
where P0: Param<TypedEventHandler<IInspectable, IItemsChangedEventArgs>>,

pub fn RemoveItemsChanged(&self, token: i64) -> Result<()>

pub fn PropChanged<P0>(&self, handler: P0) -> Result<i64>
where P0: Param<TypedEventHandler<IInspectable, IPropChangedEventArgs>>,

pub fn RemovePropChanged(&self, token: i64) -> Result<()>

pub fn Title(&self) -> Result<HSTRING>

The title of the page.

pub fn IsLoading(&self) -> Result<bool>

Indicates whether the page is currently loading.

pub fn AccentColor(&self) -> Result<OptionalColor>

The accent color of the page.