pub struct ILogMessage(/* private fields */);Expand description
The ILogMessage interface represents a log message in the Command Palette. It is used to provide information about the state of the application or specific operations, and can be used for debugging or informational purposes.
Implementations
Sourceimpl ILogMessage
impl ILogMessage
Sourcepub fn State(&self) -> Result<MessageState>
pub fn State(&self) -> Result<MessageState>
The state of the log message. This property indicates the severity or type of the log message, such as informational, warning, or error. The MessageState will specify the type.