OpenUrlCommandBuilder

Struct OpenUrlCommandBuilder 

pub struct OpenUrlCommandBuilder { /* private fields */ }
Builder for a command that opens a URL in the system’s default browser.

Implementations

Source

impl OpenUrlCommandBuilder

pub fn new(target: String) -> Self

Creates a new OpenUrlCommandBuilder with a static target URL.

pub fn new_dyn<F>(target_fn: F) -> Self
where F: Send + Sync + Fn() -> String + 'static,

Creates a new OpenUrlCommandBuilder with a function that returns the target URL.

pub fn base(self, base: ComObject<BaseCommand>) -> Self

Overrides the base command with a custom one.

By default, it uses a command with the name “Open” and an OpenInNewWindow icon “\u{E8A7}”.

pub fn result(self, result: CommandResult) -> Self

Overrides the action to be performed when the URL is opened.

By default, it is set to CommandResult::Dismiss.