pub enum ContextItem {
Separator(ComObject<SeparatorContextItem>),
Command(ComObject<CommandContextItem>),
}Expand description
Represents an item in the context menu, which can be either a separator or a command.
The IContextItem interface is used to define a context menu item in the Command Palette.
Variants
Separator(ComObject<SeparatorContextItem>)
A separator item in the context menu.
Command(ComObject<CommandContextItem>)
A command item in the context menu.