pub struct DetailsElement { /* private fields */ }Expand description
Represents a detail metadata that can be used in Details.
See: IDetailsElement
The IDetailsElement interface is used to define an element in the details view Command Palette.
Implementations
Sourceimpl DetailsElement
impl DetailsElement
Sourcepub const fn into_static(self) -> StaticComObject<Self>
pub const fn into_static(self) -> StaticComObject<Self>
This converts a partially-constructed COM object (in the sense that it contains
application state but does not yet have vtable and reference count constructed)
into a StaticComObject. This allows the COM object to be stored in static
(global) variables.
Sourceimpl DetailsElement
impl DetailsElement
Sourcepub fn new_unmanaged(key: impl Into<HSTRING>, data: DetailsData) -> Self
pub fn new_unmanaged(key: impl Into<HSTRING>, data: DetailsData) -> Self
Creates a new unmanaged instance of DetailsElement with the specified key and data.