LogMessage

Struct LogMessage 

pub struct LogMessage {
    pub state: MessageState,
    pub message: HSTRING,
}
Struct which represents a log message.

The ILogMessage interface represents a log message in the Command Palette. It is used to provide information about the state of the application or specific operations, and can be used for debugging or informational purposes.

Fields

state: MessageState

The state of the log message. This property indicates the severity or type of the log message, such as informational, warning, or error. The MessageState will specify the type.

message: HSTRING

The message text that describes the log entry.

Implementations

Source

impl LogMessage

pub const fn into_static(self) -> StaticComObject<Self>

This converts a partially-constructed COM object (in the sense that it contains application state but does not yet have vtable and reference count constructed) into a StaticComObject. This allows the COM object to be stored in static (global) variables.

Source

impl LogMessage

pub fn new(state: MessageState, message: HSTRING) -> Self

Creates a new LogMessage.

pub fn info(message: HSTRING) -> Self

Creates a new LogMessage that represents an informational message.

pub fn success(message: HSTRING) -> Self

Creates a new LogMessage that represents a success message.

pub fn warning(message: HSTRING) -> Self

Creates a new LogMessage that represents a warning message.

pub fn error(message: HSTRING) -> Self

Creates a new LogMessage that represents an error message.

pub fn log(self)

Logs the message to the host.

The message will be logged into the log file, yet not shown to the user.

This method is a convenient wrapper around the log_message function, it consumes self, so clone the struct if you want to log it multiple times.