pub struct IContentPage(/* private fields */);Expand description
The IContentPage interface is used to define a content page in the Command Palette. Content pages can be used to display additional information or resources related to the item being displayed in the Command Palette.
Implementations
Sourceimpl IContentPage
impl IContentPage
Sourcepub fn GetContent(&self) -> Result<Array<IContent>>
pub fn GetContent(&self) -> Result<Array<IContent>>
The GetContent method retrieves the content associated with the content page. This method is used to display additional information or resources related to the item being displayed in the Command Palette.
Sourcepub fn Commands(&self) -> Result<Array<IContextItem>>
pub fn Commands(&self) -> Result<Array<IContextItem>>
The commands associated with the content page.
Sourcepub fn Id(&self) -> Result<HSTRING>
pub fn Id(&self) -> Result<HSTRING>
Gets the ID of the command. This is optional but can help support more efficient command lookup in ICommandProvider::GetCommand.
Sourcepub fn ItemsChanged<P0>(&self, handler: P0) -> Result<i64>
pub fn ItemsChanged<P0>(&self, handler: P0) -> Result<i64>
Sourcepub fn RemoveItemsChanged(&self, token: i64) -> Result<()>
pub fn RemoveItemsChanged(&self, token: i64) -> Result<()>
Sourcepub fn PropChanged<P0>(&self, handler: P0) -> Result<i64>
pub fn PropChanged<P0>(&self, handler: P0) -> Result<i64>
Sourcepub fn RemovePropChanged(&self, token: i64) -> Result<()>
pub fn RemovePropChanged(&self, token: i64) -> Result<()>
Sourcepub fn AccentColor(&self) -> Result<OptionalColor>
pub fn AccentColor(&self) -> Result<OptionalColor>
The accent color of the page.