pub struct CommandContextItem_Impl { /* private fields */ }Implementations
Sourceimpl CommandContextItem_Impl
impl CommandContextItem_Impl
Sourcepub fn critical(&self) -> Result<NotifyLockReadGuard<'_, bool>>
pub fn critical(&self) -> Result<NotifyLockReadGuard<'_, bool>>
Readonly access to ICommandContextItem::IsCritical.
Makes the item red to indicate that it’s critical and requires attention.
Sourcepub fn critical_mut(&self) -> Result<NotifyLockWriteGuard<'_, bool>>
pub fn critical_mut(&self) -> Result<NotifyLockWriteGuard<'_, bool>>
Mutable access to ICommandContextItem::IsCritical.
The shortcut that was requested for this item. This property is used to define the shortcut that will be used to activate the item in the Command Palette.
Notifies the host about the property change when dropping the guard.
Sourcepub fn shortcut(&self) -> Result<NotifyLockReadGuard<'_, Option<KeyChord>>>
pub fn shortcut(&self) -> Result<NotifyLockReadGuard<'_, Option<KeyChord>>>
Readonly access to ICommandContextItem::RequestedShortcut.
The shortcut that was requested for this item. This property is used to define the shortcut that will be used to activate the item in the Command Palette.
Sourcepub fn shortcut_mut(&self) -> Result<NotifyLockWriteGuard<'_, Option<KeyChord>>>
pub fn shortcut_mut(&self) -> Result<NotifyLockWriteGuard<'_, Option<KeyChord>>>
Mutable access to ICommandContextItem::RequestedShortcut.
The shortcut that was requested for this item. This property is used to define the shortcut that will be used to activate the item in the Command Palette.
Notifies the host about the property change when dropping the guard.
Methods from Deref<Target = CommandItem_Impl>
Sourcepub fn command(
&self,
) -> Result<NotifyLockReadGuard<'_, AgileReference<ICommand>>>
pub fn command( &self, ) -> Result<NotifyLockReadGuard<'_, AgileReference<ICommand>>>
Readonly access to ICommandItem::Command.
The command associated with this item. This is the command that will be executed when the item is activated.
Sourcepub fn command_mut(
&self,
) -> Result<NotifyLockWriteGuard<'_, AgileReference<ICommand>>>
pub fn command_mut( &self, ) -> Result<NotifyLockWriteGuard<'_, AgileReference<ICommand>>>
Mutable access to ICommandItem::Command.
The command associated with this item. This is the command that will be executed when the item is activated.
Notifies the host about the property change when dropping the guard.
Sourcepub fn icon(
&self,
) -> Result<NotifyLockReadGuard<'_, Option<ComObject<IconInfo>>>>
pub fn icon( &self, ) -> Result<NotifyLockReadGuard<'_, Option<ComObject<IconInfo>>>>
Readonly access to ICommandItem::Icon.
Preferred over ICommand::Icon of self.command when displaying the icon.
The icon associated with this item. This icon will be displayed next to the item in the Command Palette.
Sourcepub fn icon_mut(
&self,
) -> Result<NotifyLockWriteGuard<'_, Option<ComObject<IconInfo>>>>
pub fn icon_mut( &self, ) -> Result<NotifyLockWriteGuard<'_, Option<ComObject<IconInfo>>>>
Mutable access to ICommandItem::Icon.
Preferred over ICommand::Icon of self.command when displaying the icon.
The icon associated with this item. This icon will be displayed next to the item in the Command Palette.
Notifies the host about the property change when dropping the guard.
Sourcepub fn title(&self) -> Result<NotifyLockReadGuard<'_, HSTRING>>
pub fn title(&self) -> Result<NotifyLockReadGuard<'_, HSTRING>>
Readonly access to ICommandItem::Title.
Preferred over ICommand::Name of self.command when displaying the title.
Note that the text displayed for default action (alongside ↲) is determined by
ICommand::Name of self.command, not this title.
The title associated with this item. This title will be displayed as the main text of the item in the Command Palette.
Sourcepub fn title_mut(&self) -> Result<NotifyLockWriteGuard<'_, HSTRING>>
pub fn title_mut(&self) -> Result<NotifyLockWriteGuard<'_, HSTRING>>
Mutable access to ICommandItem::Title.
Preferred over ICommand::Name of self.command when displaying the title.
Note that the text displayed for default action (alongside ↲) is determined by
ICommand::Name of self.command, not this title.
The title associated with this item. This title will be displayed as the main text of the item in the Command Palette.
Notifies the host about the property change when dropping the guard.
Sourcepub fn subtitle(&self) -> Result<NotifyLockReadGuard<'_, HSTRING>>
pub fn subtitle(&self) -> Result<NotifyLockReadGuard<'_, HSTRING>>
Readonly access to ICommandItem::Subtitle.
The subtitle associated with this item. This subtitle will be displayed below the item in the Command Palette.
Sourcepub fn subtitle_mut(&self) -> Result<NotifyLockWriteGuard<'_, HSTRING>>
pub fn subtitle_mut(&self) -> Result<NotifyLockWriteGuard<'_, HSTRING>>
Mutable access to ICommandItem::Subtitle.
The subtitle associated with this item. This subtitle will be displayed below the item in the Command Palette.
Notifies the host about the property change when dropping the guard.
Sourcepub fn more(&self) -> Result<NotifyLockReadGuard<'_, Vec<ContextItem>>>
pub fn more(&self) -> Result<NotifyLockReadGuard<'_, Vec<ContextItem>>>
Readonly access to ICommandItem::MoreCommands.
An array of additional commands that can be displayed in a submenu. This property is used to define a list of related commands that can be executed from the Command Palette.
Sourcepub fn more_mut(&self) -> Result<NotifyLockWriteGuard<'_, Vec<ContextItem>>>
pub fn more_mut(&self) -> Result<NotifyLockWriteGuard<'_, Vec<ContextItem>>>
Mutable access to ICommandItem::MoreCommands.
An array of additional commands that can be displayed in a submenu. This property is used to define a list of related commands that can be executed from the Command Palette.
Notifies the host about the property change when dropping the guard.